@@ -1,7 +1,7 @@
 #$Id: Relationship.pm 17677 2012-09-19 23:32:48Z jensenma $
 package REST::Neo4p::Relationship;
 use base 'REST::Neo4p::Entity';
-use REST::Neo4p::Exceptions;
+use REST::Neo4p;
 use Carp qw(croak carp);
 use strict;
 use warnings;
@@ -25,6 +25,14 @@ sub type {
   return $self->_entry->{type};
 }
 
+sub start_node {
+  return REST::Neo4p->get_node_by_id(shift->_entry->{start_id});
+}
+
+sub end_node {
+  return REST::Neo4p->get_node_by_id(shift->_entry->{end_id});
+}
+
 =head1 NAME
 
 REST::Neo4p::Relationship - Neo4j relationship object
@@ -73,6 +81,13 @@ Sets values of properties on nodes and relationships.
 
 Get all the properties of a node or relationship as a hashref.
 
+=item start_node(), end_node()
+
+ $fred_node = $married_to->start_node;
+ $wilma_node = $married_to->end_node;
+
+Get the start and end nodes of the relationship.
+
 =item type()
 
  $rel = $node->relate_to($node2, 'my_type');
